@@ -5,10 +5,11 @@ from mmpos.cli.farms import commands as farms
 from mmpos.cli.profiles import commands as profiles
 import sys
 import mmpos.api.utils as utils
+import traceback
 
 
 @click.group()
-@click.version_option(version="0.2.2", prog_name="mmpos cli")
+@click.version_option(version="0.2.3", prog_name="mmpos cli")
 @click.option(
     "--table", "format", default=True, help="Show table output", flag_value="table"
 )
@@ -39,13 +40,14 @@ def main(prog_name="mmpos"):
         os.environ["MMPOS_API_TOKEN"]
         entry_point()
     except KeyError as e:
-        if "MMPOS_API_TOKEN" in f'{e}':
+        if "MMPOS_API_TOKEN" in f"{e}":
             print("MMPOS_API_TOKEN environment variable not set")
         else:
             print(e)
         sys.exit(1)
     except Exception as e:
         print(e)
+        traceback.print_exc()
         sys.exit(1)
     finally:
         utils.cache_commit()
